==> expressmoney-points-1.25.5.tar.gz: expressmoney-points-1.25.5/expressmoney_points/il/orders.py <==
__all__ = ('OrderPoint', 'OrderObjectPoint', 'SchedulePoint')

from djmoney.contrib.django_rest_framework import MoneyField
from expressmoney.api import *

SERVICE = 'il'


class OrderCreateContract(Contract):
    requested_period = serializers.IntegerField(min_value=1)
    requested_amount = serializers.IntegerField(min_value=1)
    ip = serializers.IPAddressField()


class OrderReadContract(OrderCreateContract):
    NEW = 'NEW'
    DECLINED = 'DECLINED'
    LOAN_CREATED = 'LOAN_CREATED'
    EXPIRED = 'EXPIRED'
    STATUS_CHOICES = (
        (NEW, NEW),
        (DECLINED, DECLINED),
        (LOAN_CREATED, LOAN_CREATED),
        (EXPIRED, EXPIRED),
    )

    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    updated = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    status = serializers.ChoiceField(choices=STATUS_CHOICES)
    requested_period = serializers.IntegerField(min_value=1)
    requested_amount = MoneyField(max_digits=7, decimal_places=0)
    approved_period = serializers.IntegerField(min_value=1)
    approved_amount = MoneyField(max_digits=7, decimal_places=0, allow_null=True)
    interest_rate = serializers.DecimalField(max_digits=6, decimal_places=5, allow_null=True)
    score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
    sign = serializers.IntegerField(min_value=1)
    contract_demo = serializers.CharField(max_length=256, allow_blank=True)
    ip = serializers.IPAddressField()
    product = serializers.IntegerField()


class ScheduleReadContract(Contract):
    id = serializers.IntegerField()
    order = serializers.IntegerField()
    is_paid = serializers.BooleanField()
    date = serializers.DateField()
    amount = MoneyField(max_digits=7, decimal_places=0)


class OrderID(ID):
    _service = SERVICE
    _app = 'orders'
    _view_set = 'order'


class ScheduleID(ID):
    _service = SERVICE
    _app = 'orders'
    _view_set = 'schedule'


class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract
    _create_contract = OrderCreateContract


class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract


class SchedulePoint(ListPointMixin, ContractPoint):
    _point_id = ScheduleID()
    _read_contract = ScheduleReadContract

==> expressmoney-points-1.26.10.tar.gz: expressmoney-points-1.26.10/expressmoney_points/il/orders.py <==
__all__ = ('OrderPoint', 'OrderObjectPoint', 'SchedulePoint')

from djmoney.contrib.django_rest_framework import MoneyField
from expressmoney.api import *

SERVICE = 'il'


class OrderCreateContract(Contract):
    requested_amount = serializers.IntegerField(min_value=1)
    requested_period = serializers.IntegerField(min_value=1)
    bank_card_id = serializers.IntegerField(min_value=1)


class OrderReadContract(OrderCreateContract):
    NEW = 'NEW'
    DECLINED = 'DECLINED'
    LOAN_CREATED = 'LOAN_CREATED'
    CANCELED = "CANCELED"
    EXPIRED = 'EXPIRED'
    STATUS_CHOICES = (
        (NEW, NEW),
        (DECLINED, DECLINED),
        (LOAN_CREATED, LOAN_CREATED),
        (CANCELED, CANCELED),
        (EXPIRED, EXPIRED),
    )

    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    updated = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    approved_amount = MoneyField(max_digits=7, decimal_places=0, allow_null=True)
    approved_period = serializers.IntegerField(min_value=1)
    product = serializers.IntegerField()
    status = serializers.ChoiceField(choices=STATUS_CHOICES)
    contract_demo = serializers.CharField(max_length=256, allow_blank=True)


class ScheduleReadContract(Contract):
    id = serializers.IntegerField()
    order = serializers.IntegerField()
    payments_number = serializers.IntegerField()
    date = serializers.DateField()
    amount = MoneyField(max_digits=7, decimal_places=0)
    amount_total = MoneyField(max_digits=7, decimal_places=0)
    amount_interests = MoneyField(max_digits=7, decimal_places=0)
    amount_body = MoneyField(max_digits=7, decimal_places=0)
    body_left_to_pay = MoneyField(max_digits=7, decimal_places=0)
    is_paid = serializers.BooleanField()


class OrderID(ID):
    _service = SERVICE
    _app = 'orders'
    _view_set = 'order'


class ScheduleID(ID):
    _service = SERVICE
    _app = 'orders'
    _view_set = 'schedule'


class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract
    _create_contract = OrderCreateContract


class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract


class SchedulePoint(ListPointMixin, ContractPoint):
    _point_id = ScheduleID()
    _read_contract = ScheduleReadContract
